@@ -1406,8 +1406,8 @@ class Builder(Update):
                                             key=lambda x:x[0])):
                 package, required_pkgs = data
 
-                self.startTask("Check (%d of %d) %s" % (
-                    i + 1, len(check_data), package))
+                self.startTask(_("Check ({cur} of {maxval}) {package}").format(
+                    cur=i + 1, maxval=len(check_data), package=package))
 
                 if not required_pkgs:
                     self.endTask(True)
@@ -1416,7 +1416,7 @@ class Builder(Update):
                 pretend = list(self.pretend_emerge_list(builder_path, package))
                 if not pretend:
                     self.endTask(False)
-                    self.printERROR("Failed to receive package list")
+                    self.printERROR(_("Failed to receive package list"))
                 else:
                     # получаем список пакетов которые необходимых для работы
                     required_pkgs = [x for x in required_pkgs
@@ -1460,18 +1460,21 @@ class Builder(Update):
         for pkg, reqs in automagic.items():
             if reqs:
                 self.printWARNING(
-                    "Auto depends for %s package by %s will be used" % (
-                        pkg, ",".join(str(x) for x in reqs)))
-        for pkg, clear_req_pkgs in automagic_clear.items():
+                    _("Auto depends for {pkg} package by {pkgs} "
+                      "will be used").format(
+                        pkg=pkg, pkgs=",".join(str(x) for x in reqs)))
+            clear_req_pkgs = automagic_clear.get(pkg, [])
             if clear_req_pkgs:
                 self.printWARNING(
-                    "Auto depends for %s package by %s will be clear" % (
-                        pkg, ",".join(str(x) for x in clear_req_pkgs)))
-        for pkg, waste_pkgs in automagic_waste.items():
+                    _("Auto depends for {pkg} package by {pkgs} "
+                      "will be clear").format(
+                        pkg=pkg, pkgs=",".join(str(x) for x in clear_req_pkgs)))
+            waste_pkgs = automagic_waste.get(pkg, [])
             if waste_pkgs:
                 self.printWARNING(
-                    "Specified depends for %s package by %s obsoleted" % (
-                        pkg, ",".join(waste_pkgs)))
+                    _("Specified depends for {pkg} package by {pkgs} "
+                      "obsoleted").format(
+                        pkg=pkg, pkgs=",".join(waste_pkgs)))
 
     def _rebuild_automagic(self, automagic, automagic_clear, builder_path):
         """
