@@ -18,10 +18,11 @@ import sys
 from calculate.core.server.func import Action, Tasks
 from calculate.lib.cl_lang import setLocalTranslate, getLazyLocalTranslate
 from calculate.lib.cl_template import TemplatesError
-from calculate.lib.utils.files import FilesError
+from calculate.lib.utils.files import FilesError, isEmptyFile, readFile
 from calculate.update.emerge_parser import EmergeError
 from calculate.update.update import UpdateError
 from ..datavars import BuilderError
+from os import path
 from calculate.lib.utils.git import GitError
 from calculate.lib.utils.portage import (EmergeLogNamedTask,
                                          PackageList, EmergeLog)
@@ -52,6 +53,21 @@ class BuilderConditions(object):
 
         return func
 
+    @staticmethod
+    def force_automagic(Get):
+        cache_list = ("/var/calculate/tmp/%s.checkdep" %
+                      Get("cl_builder_id_path"))
+        return not isEmptyFile(cache_list, grab=True)
+
+    @staticmethod
+    def force_preserved(Get):
+        pfile = path.join(Get("cl_builder_path"),
+                          "var/lib/portage/preserved_libs_registry")
+        content = readFile(pfile).strip()
+        if not content or content == '{}':
+            return False
+        else:
+            return True
 
 class ClBuilderUpdateAction(Action):
     """
@@ -105,7 +121,7 @@ class ClBuilderUpdateAction(Action):
                       'message':
                           __("Fallback syncing the {eachvar:capitalize} "
                              "repository"),
-                      'method': 'Builder.syncRepositories(eachvar)',
+                      'method': 'Builder.syncRepositories(eachvar,True)',
                       'condition': lambda Get: (
                           Get('cl_builder_binary_set') == "on" and
                           not Get('update.cl_update_binhost_data')[0])
@@ -127,8 +143,7 @@ class ClBuilderUpdateAction(Action):
                       },
                      {'name': 'sync_reps',
                       'foreach': 'cl_builder_sync_rep',
-                      'message': __(
-                          "Syncing the {eachvar:capitalize} repository"),
+                      'message': __("Checking {eachvar:capitalize} updates"),
                       'method': 'Builder.syncRepositories(eachvar)',
                       'condition': lambda Get: Get('cl_builder_sync_rep')
                       },
@@ -181,6 +196,17 @@ class ClBuilderUpdateAction(Action):
                           Get('update.cl_update_cleanpkg_set') == 'on'),
                       'essential': False
                       },
+                     {'name': 'update_packages_cache',
+                      'message': __("Update packages index"),
+                      'method': 'Builder.download_packages('
+                                'update.cl_update_portage_binhost,'
+                                'update.cl_update_package_cache)',
+                      'essential': False,
+                      'condition': lambda Get: (
+                          Get('update.cl_update_package_cache') and (
+                              Get('builder.cl_builder_outdate_set') == 'on' or
+                              Get('update.cl_update_package_cache_set') == 'on'))
+                      },
                      # сообщение удачного завершения при обновлении репозиториев
                      {'name': 'success_syncrep',
                       'message': __("Synchronization finished"),
@@ -215,7 +241,7 @@ class ClBuilderUpdateAction(Action):
                       'method': 'Builder.emerge_ask('
                                 'update.cl_update_pretend_set,'
                                 '"-uDN","--changed-deps",'
-                                '"--with-bdeps=y","@world")'
+                                '"@world")'
                       }
                  ],
                  'condition': lambda Get: (
@@ -239,21 +265,6 @@ class ClBuilderUpdateAction(Action):
                       }
                  ]
                  },
-                {'name': 'update_other:update_python',
-                 'group': __("Updating Python"),
-                 'tasks': [
-                     {'name': 'python_updater',
-                      'message': __('Find & rebuild packages broken due '
-                                    'to a Python upgrade'),
-                      'method': 'Builder.chroot_emergelike(cl_builder_path,'
-                                '"python-updater")',
-                      'condition': BuilderConditions.was_installed(
-                          'dev-lang/python$', EmergeMark.PythonUpdater),
-                      'decoration': 'Builder.update_task("%s")' %
-                                    EmergeMark.PythonUpdater
-                      },
-                 ]
-                 },
                 {'name': 'update_other:update_perl',
                  'group': __("Updating Perl"),
                  'tasks': [
@@ -275,7 +286,7 @@ class ClBuilderUpdateAction(Action):
                  'tasks': [
                      {'name': 'update_depclean',
                       'message': __("Calculating dependencies"),
-                      'method': 'Builder.depclean()',
+                      'method': 'Builder.depclean(cl_builder_clean_bdeps_set)',
                       },
                  ]
                  },
@@ -304,8 +315,10 @@ class ClBuilderUpdateAction(Action):
                       'message': __('Updating preserved libraries'),
                       'method': 'Builder.emerge(cl_builder_path,"",'
                                 '"@preserved-rebuild")',
-                      'condition': BuilderConditions.was_installed(
-                          '.*', EmergeMark.PreservedLibs),
+                      'condition': lambda Get: (
+                          BuilderConditions.was_installed(
+                              '.*', EmergeMark.PreservedLibs) or
+                          BuilderConditions.force_preserved(Get)),
                       'decoration': 'Builder.update_task("%s")' %
                                     EmergeMark.PreservedLibs
                       },
@@ -320,6 +333,27 @@ class ClBuilderUpdateAction(Action):
                       'decoration': 'Builder.update_task("%s")' %
                                     EmergeMark.RevdepRebuild
                       },
+                 ],
+                 'depend': Tasks.has("update_other")
+                 },
+                {'name': 'update_other:check_automagic_group',
+                 'group': __("Check for auto depends"),
+                 'tasks': [
+                     {'name': 'check_automagic',
+                      'method': 'Builder.check_automagic(cl_builder_path)',
+                      'condition': lambda Get: (
+                          Get('builder.cl_builder_check_automagic_set') == 'on'
+                          and (BuilderConditions.was_installed(
+                              '.*', EmergeMark.Automagic)(Get) or
+                               BuilderConditions.force_automagic(Get))),
+                      'decoration': 'Builder.update_task("%s")' %
+                                    EmergeMark.Automagic
+                      },
+                 ]
+                 },
+                {'name': 'update_world:update_configures',
+                 'group': __("Completion of the system update"),
+                 'tasks': [
                      {'name': 'update_world:dispatch_conf_end',
                       'message': __("Updating configuration files"),
                       'method': 'Builder.dispatchConf(None,cl_builder_path)',
@@ -334,13 +368,18 @@ class ClBuilderUpdateAction(Action):
                  ],
                  'depend': Tasks.has("update_other")
                  },
-                {'name': 'update_other:reading_news',
-                 'method': 'Builder.reading_news(cl_builder_path)',
-                 'essential': False
+                {'name': 'update_other:reading_news_group',
+                 'group': __("Last news:"),
+                 'tasks': [
+                     {'name': 'update_other:reading_news',
+                      'method': 'Builder.reading_news(cl_builder_path)',
+                      'essential': False
+                      },
+                 ]
                  },
                 {'name': 'update_other:check_obsolete',
                  'method': 'Builder.check_obsolete(cl_builder_path)'
-                 }
+                 },
             ] + [
                 {'name': 'failed',
                  'error': __("Failed to update the system"),
